@@ -1,9 +1,5 @@
 from glapi import configuration
 from glapi.connection import GitlabConnection
-from glapi.epic import GitlabEpic
-from glapi.issue import GitlabIssue
-from glapi.project import GitlabProject
-from glapi.user import GitlabUser
 
 class GitlabGroup:
     """
@@ -52,24 +48,11 @@ class GitlabGroup:
         if self.id and self.connection.token and self.connection.version:
 
             # query api
-            epics = self.connection.paginate(
+            result = self.connection.paginate(
                 endpoint="groups/%s/epics" % self.id,
                 params=params
             )
 
-            # generate GitlabEpic
-            result = [
-                GitlabEpic(
-                    epic=d,
-                    group_users=group_users,
-                    get_issues=get_issues,
-                    get_notes=get_notes,
-                    get_participants=get_participants,
-                    token=self.connection.token,
-                    version=self.connection.version
-                ) for d in epics
-            ]
-
         return result
 
     def extract_issues(self, scope: str = "all", date_start: str = None, date_end: str = None, get_notes: bool = False, get_links: bool = False, get_participants: bool = False) -> list:
@@ -100,14 +83,11 @@ class GitlabGroup:
         if self.id and self.connection.token and self.connection.version:
 
             # query api
-            issues = self.connection.paginate(
+            result = self.connection.paginate(
                 endpoint="groups/%s/issues" % self.id,
                 params=params
             )
 
-            # generate GitlabIssue
-            result = [GitlabIssue(issue=d, get_links=get_links, get_notes=get_notes, get_participants=get_participants, token=self.connection.token, version=self.connection.version) for d in issues]
-
         return result
 
     def extract_projects(self, date_start: str = None, date_end: str = None) -> list:
@@ -134,14 +114,11 @@ class GitlabGroup:
         if self.id and self.connection.token and self.connection.version:
 
             # query api
-            projects = self.connection.paginate(
+            result = self.connection.paginate(
                 endpoint="groups/%s/projects" % self.id,
                 params=params
             )
 
-            # generate GitlabProject
-            result = [GitlabProject(project=d) for d in projects]
-
         return result
 
     def extract_users(self) -> list:
@@ -158,11 +135,8 @@ class GitlabGroup:
         if self.id and self.connection.token and self.connection.version:
 
             # query api
-            users = self.connection.paginate(
+            result = self.connection.paginate(
                 endpoint="groups/%s/members" % self.id
             )
 
-            # generate GitlabUser
-            result = [GitlabUser(user=d) for d in users]
-
         return result
